import { SelectStatement } from './SelectStatement';
import { UpdateStatement } from './UpdateStatement';
import { InsertStatement } from './InsertStatement';
import { DeleteStatement } from './DeleteStatement';
import { CreateColumnFamilyStatement } from './CreateColumnFamilyStatement';
import { CreateKeyspaceStatement } from './CreateKeyspaceStatement';
import { CreateColumnFamilyIndexStatement } from './CreateColumnFamilyIndexStatement';
import { CreateMaterializedViewStatement } from './CreateMaterializedViewStatement';
import { Raw } from './Raw';
export interface BuilderOptions {
}
export declare type Statement = SelectStatement | UpdateStatement | DeleteStatement | InsertStatement | CreateKeyspaceStatement | CreateColumnFamilyStatement | CreateColumnFamilyIndexStatement | CreateMaterializedViewStatement;
export declare class Builder {
    readonly options?: BuilderOptions | undefined;
    static Update: typeof UpdateStatement;
    static Insert: typeof InsertStatement;
    static Delete: typeof DeleteStatement;
    static CreateKeyspace: typeof CreateKeyspaceStatement;
    static CreateColumnFamily: typeof CreateColumnFamilyStatement;
    static CreateColumnFamilyIndex: typeof CreateColumnFamilyIndexStatement;
    static CreateMaterializedView: typeof CreateMaterializedViewStatement;
    constructor(options?: BuilderOptions | undefined);
    token(values: (any | Raw)[]): Raw;
    token(...columns: (string | Raw)[]): Raw;
    now(): Raw;
    ttl(column: string | Raw): Raw;
    timestamp(column: string | Raw): Raw;
    key(column: string | Raw, key: any): Raw;
    createKeyspace(name: string | Raw): CreateKeyspaceStatement<{}>;
    createIndex(column: string | Raw, name?: string | Raw): CreateColumnFamilyIndexStatement;
    createIndex(column: [string | Raw, 'FULL' | 'ENTRIES' | 'KEYS' | 'VALUES'], name?: string | Raw): CreateColumnFamilyIndexStatement;
    createColumnFamily(name: string | Raw): CreateColumnFamilyStatement;
    createColumnFamily(keyspace: string, name: string): CreateColumnFamilyStatement;
    createMaterializedView(name: string | Raw): CreateMaterializedViewStatement;
    createMaterializedView(keyspace: string, name: string): CreateMaterializedViewStatement;
    select(name: string | Raw): SelectStatement;
    select(keyspace: string, name: string): SelectStatement;
    select(): SelectStatement;
    insert(name: string | Raw): InsertStatement;
    insert(keyspace: string, name: string): InsertStatement;
    insert(): InsertStatement;
    update(name: string | Raw): UpdateStatement;
    update(keyspace: string, name: string): UpdateStatement;
    update(): UpdateStatement;
    delete(name: string | Raw): DeleteStatement;
    delete(keyspace: string, name: string): DeleteStatement;
    delete(): DeleteStatement;
    filterResult(result: any): any;
    mapRow(index: number, row: any): any;
}
